@@ -1,3 +1,5 @@
+import warnings
+
 from requests.auth import HTTPBasicAuth
 
 from py42.exceptions import Py42Error
@@ -7,6 +9,8 @@ from py42.services._auth import CustomJWTAuth
 from py42.services._connection import Connection
 from py42.usercontext import UserContext
 
+warnings.simplefilter("always", DeprecationWarning)
+
 
 def from_local_account(host_address, username, password, totp=None):
     """Creates a :class:`~py42.sdk.SDKClient` object for accessing the Code42 REST APIs using the
@@ -249,6 +253,24 @@ class SDKClient:
         """
         return self._clients.trustedactivities
 
+    @property
+    def userriskprofile(self):
+        """A collection of methods and properties for managing user risk profiles.
+
+        Returns:
+            :class:`py42.clients.userriskprofile.UserRiskProfileClient`
+        """
+        return self._clients.userriskprofile
+
+    @property
+    def watchlists(self):
+        """A collection of methods and properties for managing watchlists.
+
+        Returns:
+            :class:`py42.clients.watchlists.WatchlistsClient`
+        """
+        return self._clients.watchlists
+
 
 def _init_services(main_connection, main_auth):
     # services are imported within function to prevent circular imports when a service
@@ -273,6 +295,8 @@ def _init_services(main_connection, main_auth):
     from py42.services.savedsearch import SavedSearchService
     from py42.services.trustedactivities import TrustedActivitiesService
     from py42.services.users import UserService
+    from py42.services.watchlists import WatchlistsService
+    from py42.services.userriskprofile import UserRiskProfileService
 
     alert_rules_key = "FedObserver-API_URL"
     alerts_key = "AlertService-API_URL"
@@ -283,6 +307,7 @@ def _init_services(main_connection, main_auth):
     audit_logs_key = "AUDIT-LOG_API-URL"
     cases_key = "CASES_API-URL"
     trusted_activities_key = "TRUSTED-DOMAINS_API-URL"
+    watchlists_key = "watchlists-API_URL"
 
     kv_connection = Connection.from_microservice_prefix(main_connection, kv_prefix)
     kv_service = KeyValueStoreService(kv_connection)
@@ -314,6 +339,9 @@ def _init_services(main_connection, main_auth):
     trusted_activities_conn = Connection.from_microservice_key(
         kv_service, trusted_activities_key, auth=main_auth
     )
+    watchlists_conn = Connection.from_microservice_key(
+        kv_service, watchlists_key, auth=main_auth
+    )
 
     services = Services(
         administration=administration_svc,
@@ -336,6 +364,8 @@ def _init_services(main_connection, main_auth):
         cases=CasesService(cases_conn),
         casesfileevents=CasesFileEventsService(cases_conn),
         trustedactivities=TrustedActivitiesService(trusted_activities_conn),
+        userriskprofile=UserRiskProfileService(watchlists_conn),
+        watchlists=WatchlistsService(watchlists_conn),
     )
 
     return services, user_ctx
@@ -358,6 +388,8 @@ def _init_clients(services, connection):
     from py42.clients.trustedactivities import TrustedActivitiesClient
     from py42.services.storage._service_factory import ConnectionManager
     from py42.services.storage._service_factory import StorageServiceFactory
+    from py42.clients.userriskprofile import UserRiskProfileClient
+    from py42.clients.watchlists import WatchlistsClient
 
     authority = AuthorityClient(
         administration=services.administration,
@@ -388,6 +420,8 @@ def _init_clients(services, connection):
     auditlogs = AuditLogsClient(services.auditlogs)
     loginconfig = LoginConfigurationClient(connection)
     trustedactivities = TrustedActivitiesClient(services.trustedactivities)
+    userriskprofile = UserRiskProfileClient(services.userriskprofile)
+    watchlists = WatchlistsClient(services.watchlists)
     clients = Clients(
         authority=authority,
         detectionlists=detectionlists,
@@ -398,5 +432,7 @@ def _init_clients(services, connection):
         cases=CasesClient(services.cases, services.casesfileevents),
         loginconfig=loginconfig,
         trustedactivities=trustedactivities,
+        userriskprofile=userriskprofile,
+        watchlists=watchlists,
     )
     return clients
