@@ -6,25 +6,25 @@ class EmailPolicyName(QueryFilterStringField):
     emails sent via Microsoft Office 365 only).
     """
 
-    _term = u"emailDlpPolicyNames"
+    _term = "emailDlpPolicyNames"
 
 
 class EmailSubject(QueryFilterStringField):
     """Class that filters events based on the email's subject (applies to email events only)."""
 
-    _term = u"emailSubject"
+    _term = "emailSubject"
 
 
 class EmailRecipients(QueryFilterStringField):
     """Class that filters events based on the email's recipient list (applies to email events only)."""
 
-    _term = u"emailRecipients"
+    _term = "emailRecipients"
 
 
 class EmailSender(QueryFilterStringField):
     """Class that filters events based on the email's sender (applies to email events only)."""
 
-    _term = u"emailSender"
+    _term = "emailSender"
 
 
 class EmailFrom(QueryFilterStringField):
@@ -32,4 +32,4 @@ class EmailFrom(QueryFilterStringField):
     the \"From:\" field in the email (applies to email events only).
     """
 
-    _term = u"emailFrom"
+    _term = "emailFrom"
