@@ -11,18 +11,16 @@ verify_ssl_certs = True
 items_per_page = 500
 security_events_per_page = 10000
 
-_custom_user_suffix = u""
-_python_version = u"{}.{}.{}".format(
-    sys.version_info[0], sys.version_info[1], sys.version_info[2]
-)
+_custom_user_suffix = ""
+_python_version = f"{sys.version_info[0]}.{sys.version_info[1]}.{sys.version_info[2]}"
 
 
 def get_user_agent_string():
-    return u"py42 {} python {}{}".format(
+    return "py42 {} python {}{}".format(
         __version__, _python_version, _custom_user_suffix
     )
 
 
 def set_user_agent_suffix(suffix):
     global _custom_user_suffix
-    _custom_user_suffix = u" {}".format(suffix)
+    _custom_user_suffix = f" {suffix}"
